@@ -1,6 +1,6 @@
 """
 # -*- coding: utf-8 -*-
-#====================================================================================================================
+#===============================================================================
 #
 # Copyright (C) 2013/2014 Laurent Champagnac
 #
@@ -16,8 +16,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#====================================================================================================================
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#===============================================================================
 """
 
 # Logger
@@ -83,7 +83,7 @@ class TcpSocketManager(object):
         try:
             del socToClose
         except Exception as e:
-            logger.debug("Socket delm ex=%s", SolBase.exToStr(e))
+            logger.debug("Socket del ex=%s", SolBase.exToStr(e))
 
     def __init__(self, callbackDisconnect, callbackReceive, onReceiveProfileSelf=False):
         """
@@ -183,13 +183,13 @@ class TcpSocketManager(object):
             logger.debug("__sheduleSslHandshakeTimeOut : ms=%s, self=%s", self.__sslHandshakeTimeoutMs, self)
             self.__sslTimeoutGreenlet = gevent.spawn_later(self.__sslHandshakeTimeoutMs * 0.001, self.__onSslTimeout)
 
-    def _unsheduleSslHandshakeTimeOut(self):
+    def _unscheduleSslHandshakeTimeOut(self):
         """
         Unschedule the ssl timeout
         :return: Nothing
         """
         with self.__sslLocker:
-            logger.debug("_unsheduleSslHandshakeTimeOut, self=%s", self)
+            logger.debug("_unscheduleSslHandshakeTimeOut, self=%s", self)
 
             if not self.__sslTimeoutGreenlet is None:
                 self.__sslTimeoutGreenlet.kill()
@@ -208,10 +208,10 @@ class TcpSocketManager(object):
         logger.debug("__onSslTimeout, self=%s", self)
 
         # Check
-        if self.__sslHandshakePending == False:
+        if not self.__sslHandshakePending:
             # Done, exit
             return
-        elif self.__isRunning() == False:
+        elif not self.__isRunning():
             # Not connected, exit
             return
 
@@ -219,7 +219,7 @@ class TcpSocketManager(object):
         logger.warn("handshake timeout, fatal, ms=%s, self=%s", self.__sslHandshakeTimeoutMs, self)
 
         # Stat
-        MeterManager.get(TcpServerStat).sslHandshakeTimeoutCout.increment()
+        MeterManager.get(TcpServerStat).sslHandshakeTimeoutCount.increment()
 
         # Timeout, Fatal, exit now
         self._disconnectHelper("__onSslTimeout")
@@ -230,7 +230,7 @@ class TcpSocketManager(object):
 
     def setSslHandshakeAsynch(self, sslHandshakeAsynchEnable, sslHandshakeTimeoutMs, sslWaitDebugMs=None):
         """
-        Enable or disable ssl asynch hanshake.
+        Enable or disable ssl asynch handshake.
         :param sslHandshakeAsynchEnable: Boolean. If True, will enable it.
         :param sslHandshakeTimeoutMs: Apply if asynch handshake is enable. Timeout in ms for handshake itself.
         :param sslWaitDebugMs: Debug only.
@@ -242,7 +242,7 @@ class TcpSocketManager(object):
         self.__sslWaitDebugMs = sslWaitDebugMs
 
         # If enable, switch to pending true
-        if self.__sslHandshakeAsynch == True:
+        if self.__sslHandshakeAsynch:
             # Now pending
             self.__sslHandshakePending = True
 
@@ -349,13 +349,13 @@ class TcpSocketManager(object):
         """
 
         # Check
-        if isinstance(bufferToSend, str) == False:
+        if not isinstance(bufferToSend, str):
             logger.error("TcpSocketManager : sendBinaryToSocket : bufferToSend not a binary, class=%s, self=%s",
                          SolBase.getClassName(bufferToSend), self)
             return False
 
         # Check
-        if self.__isRunning() == False:
+        if not self.__isRunning():
             logger.debug("TcpSocketManager : sendBinaryToSocket : not connected, returning false, self=%s", self)
             return False
 
@@ -378,21 +378,21 @@ class TcpSocketManager(object):
         """
 
         # Check
-        if isinstance(signaledBuffer, SignaledBuffer) == False:
+        if not isinstance(signaledBuffer, SignaledBuffer):
             logger.error(
                 "TcpSocketManager : sendBinaryToSocketWithSignal : signaledBuffer not a SignaledBuffer, class=%s, self=%s",
                 SolBase.getClassName(signaledBuffer), self)
             return False
 
             # Check
-        if isinstance(signaledBuffer.binaryBuffer, str) == False:
+        if not isinstance(signaledBuffer.binaryBuffer, str):
             logger.error(
                 "TcpSocketManager : sendBinaryToSocketWithSignal : binaryBuffer not a binary, class=%s, self=%s",
                 SolBase.getClassName(signaledBuffer.binaryBuffer), self)
             return False
 
         # Check
-        if self.__isRunning() == False:
+        if not self.__isRunning():
             logger.debug("TcpSocketManager : sendBinaryToSocketWithSignal : not connected, returning false, self=%s",
                          self)
             return False
@@ -414,13 +414,13 @@ class TcpSocketManager(object):
         """
 
         # Check
-        if isinstance(textToSend, str) == False:
+        if not isinstance(textToSend, str):
             logger.error("TcpSocketManager : sendTextToSocket : textToSend not an str, class=%s, buf=%s, self=%s",
                          SolBase.getClassName(textToSend), repr(textToSend), self)
             return False
 
         # Enqueue
-        if appendLF == True:
+        if appendLF:
             return self.sendBinaryToSocket(textToSend + "\n")
         else:
             return self.sendBinaryToSocket(textToSend)
@@ -435,7 +435,7 @@ class TcpSocketManager(object):
         """
 
         # Check
-        if isinstance(unicodeToSend, unicode) == False:
+        if not isinstance(unicodeToSend, unicode):
             logger.error(
                 "TcpSocketManager : sendUnicodeToSocket : unicodeToSend not an unicode, class=%s, unicode=%s, self=%s",
                 SolBase.getClassName(unicodeToSend), repr(unicodeToSend), self)
@@ -445,7 +445,7 @@ class TcpSocketManager(object):
         unicodeTemp = unicodeToSend
 
         # LF if required
-        if appendLF == True:
+        if appendLF:
             unicodeTemp += u"\n"
 
         # Convert to binary localBuffer
@@ -475,7 +475,7 @@ class TcpSocketManager(object):
 
     def _disconnectHelper(self, reason):
         """
-        Fire a disconnect on our end and notify upper level is possibvle
+        Fire a disconnect on our end and notify upper level is possible
         :param reason: Reason
         :type reason: str
         """
@@ -517,7 +517,7 @@ class TcpSocketManager(object):
         """
 
         # Check
-        if self.__isRunning() == False:
+        if not self.__isRunning():
             logger.debug("TcpSocketManager : _waitForSocketRecv : not connected, returning false, self=%s", self)
             return False
 
@@ -539,7 +539,7 @@ class TcpSocketManager(object):
         """
 
         # Check
-        if self.__isRunning() == False:
+        if not self.__isRunning():
             logger.debug("TcpSocketManager : _waitForSocketSend : not connected, returning false, self=%s", self)
             return False
 
@@ -580,9 +580,9 @@ class TcpSocketManager(object):
         """
         logger.debug("TcpSocketManager : _readLoopInternal : entering now, self=%s", self)
         try:
-            while self.__isRunning() == True:
+            while self.__isRunning():
                 try:
-                    if self.__sslHandshakePending == True:
+                    if self.__sslHandshakePending:
                         # Pending SSL handshake + received something
                         # Handle SSL handshake now
 
@@ -604,7 +604,7 @@ class TcpSocketManager(object):
                         self.currentSocket.do_handshake()
 
                         # Done, cancel timeout
-                        self._unsheduleSslHandshakeTimeOut()
+                        self._unscheduleSslHandshakeTimeOut()
 
                         # Ms
                         ms = SolBase.dateDiff(self._dtLastRecv)
@@ -627,11 +627,11 @@ class TcpSocketManager(object):
 
                     # Wait for socket to be available for read
                     ok = self._waitForSocketRecv()
-                    if ok == False:
+                    if not ok:
                         # This is not really normal
                         logger.warn("TcpSocketManager : _readLoopInternal : _waitForSocketRecv returned False, self=%s",
                                     self)
-                    elif self.__isRunning() == False:
+                    elif not self.__isRunning():
                         logger.debug(
                             "TcpSocketManager : _readLoopInternal : _waitForSocketRecv returned True, __isRunning()==False, exiting, self=%s",
                             self)
@@ -639,7 +639,7 @@ class TcpSocketManager(object):
                     else:
                         # Something to read...
                         localBuffer = self._readFromSocket()
-                        if self.__isRunning() == False:
+                        if not self.__isRunning():
                             logger.debug(
                                 "TcpSocketManager : _readLoopInternal : _readFromSocket returned, __isRunning()==False, exiting, self=%s",
                                 self)
@@ -659,7 +659,7 @@ class TcpSocketManager(object):
                             # Notify
                             if not self._callbackReceive is None:
                                 # Self provide ?
-                                if self._onReceiveProfileSelf == True:
+                                if self._onReceiveProfileSelf:
                                     self._callbackReceive(localBuffer, self)
                                 else:
                                     self._callbackReceive(localBuffer)
@@ -687,7 +687,7 @@ class TcpSocketManager(object):
         """
 
         # Check
-        if self.__isRunning() == False:
+        if not self.__isRunning():
             logger.debug("TcpSocketManager : _readFromSocket : not connected, doing nothing, self=%s", self)
             return None
 
@@ -755,7 +755,7 @@ class TcpSocketManager(object):
         """
         logger.debug("TcpSocketManager : _writeLoopInternal : entering now, self=%s", self)
         try:
-            while self.__isRunning() == True:
+            while self.__isRunning():
                 try:
                     # Wait for the queue
                     try:
@@ -768,14 +768,14 @@ class TcpSocketManager(object):
                         continue
 
                     # Go some
-                    if isinstance(item, str) == True:
+                    if isinstance(item, str):
                         # Length
                         length = len(item)
                         # Buffer to send
                         bufToSend = item
                         # Event to signal
                         eventToSignal = None
-                    elif isinstance(item, SignaledBuffer) == True:
+                    elif isinstance(item, SignaledBuffer):
                         # Stats
                         length = len(item.binaryBuffer)
                         # Buffer to send
@@ -795,11 +795,11 @@ class TcpSocketManager(object):
                     logger.debug("TcpSocketManager : _writeLoopInternal : waiting for socket to send=%s, self=%s",
                                  repr(item), self)
                     ok = self._waitForSocketSend()
-                    if ok == False:
+                    if not ok:
                         # This is not really normal
                         logger.warn(
                             "TcpSocketManager : _writeLoopInternal : _waitForSocketSend returned False, self=%s", self)
-                    elif self.__isRunning() == False:
+                    elif not self.__isRunning():
                         logger.debug(
                             "TcpSocketManager : _writeLoopInternal : Ready for send, but __isRunning==False, exiting, send=%s, self=%s",
                             self)
@@ -811,7 +811,7 @@ class TcpSocketManager(object):
                                 "TcpSocketManager : _writeLoopInternal : writing to socket to send=%s, self=%s",
                                 repr(item), self)
                             ok = self._writeToSocket(bufToSend)
-                            if ok == False:
+                            if not ok:
                                 # This is not really normal
                                 logger.warn(
                                     "TcpSocketManager : _writeLoopInternal : _writeToSocket returned False, self=%s",
@@ -845,7 +845,7 @@ class TcpSocketManager(object):
         """
 
         # Check
-        if self.__isRunning() == False:
+        if not self.__isRunning():
             logger.debug("TcpSocketManager : _writeToSocket : not connected, doing nothing, self=%s", self)
             return False
 
